# How-to Guides

Practical step-by-step guides for the more experienced user.

```{toctree}
:maxdepth: 1
:glob:

how-to/create-generic-ioc-repo.md
how-to/convert-ioc-instance.md
how-to/autosave.md
how-to/verify-with-devcontainer.md
how-to/create-converter
how-to/contribute
```
